==> tenor-1.0.4.tar.gz: lib/src/model/tenor_result.dart <==
part of tenor;

class TenorResult {
  bool hasCaption;
  bool hasaudio;
  int shares;
  String id;
  String title;
  String created;
  String url;
  String itemurl;
  TenorGif media;
  TenorResult({
    this.hasCaption,
    this.hasaudio,
    this.shares,
    this.id,
    this.title,
    this.created,
    this.url,
    this.itemurl,
    this.media,
  });

  Map<String, dynamic> toMap() {
    return {
      'hasCaption': hasCaption,
      'hasaudio': hasaudio,
      'shares': shares,
      'id': id,
      'title': title,
      'created': created,
      'url': url,
      'itemurl': itemurl,
      'media': media?.toMap(),
    };
  }

  factory TenorResult.fromMap(Map<String, dynamic> map) {
    if (map == null) return null;

    return TenorResult(
      hasCaption: map['hascaption'],
      hasaudio: map['hasaudio'],
      shares: map['shares'],
      id: map['id'],
      title: map['title'],
      created: '${map['created']}',
      url: map['url'],
      itemurl: map['itemurl'],
      media: TenorGif.fromMap((map != null &&
              map['media'] != null &&
              (map['media'] is List && map['media'].length != 0))
          ? map['media'][0]
          : <String, dynamic>{}),
    );
  }

  String toJson() => json.encode(toMap());

  factory TenorResult.fromJson(String source) =>
      TenorResult.fromMap(json.decode(source));

  @override
  String toString() {
    return 'TenorResult(hasCaption: $hasCaption, hasaudio: $hasaudio, shares: $shares, id: $id, title: $title, created: $created, url: $url, itemurl: $itemurl, media: $media)';
  }

  @override
  bool operator ==(Object o) {
    if (identical(this, o)) return true;

    return o is TenorResult &&
        o.hasCaption == hasCaption &&
        o.hasaudio == hasaudio &&
        o.shares == shares &&
        o.id == id &&
        o.title == title &&
        o.created == created &&
        o.url == url &&
        o.itemurl == itemurl &&
        o.media == media;
  }

  @override
  int get hashCode {
    return hasCaption.hashCode ^
        hasaudio.hashCode ^
        shares.hashCode ^
        id.hashCode ^
        title.hashCode ^
        created.hashCode ^
        url.hashCode ^
        itemurl.hashCode ^
        media.hashCode;
  }
}

==> tenor-1.0.8.tar.gz: lib/src/model/tenor_result.dart <==
part of tenor;

// ignore: must_be_immutable
class TenorResult extends Equatable {
  bool hasCaption = false;
  bool hasaudio = false;
  int shares;
  String id;
  String title;
  String created;
  String url;
  String itemurl;
  TenorGif media;
  TenorResult({
    this.hasCaption = false,
    this.hasaudio = false,
    this.shares = 0,
    this.id,
    this.title,
    this.created,
    this.url,
    this.itemurl,
    this.media,
  });

  Map<String, dynamic> toMap() {
    return {
      'hasCaption': hasCaption,
      'hasaudio': hasaudio,
      'shares': shares,
      'id': id,
      'title': title,
      'created': created,
      'url': url,
      'itemurl': itemurl,
      'media': media?.toMap(),
    };
  }

  static TenorResult fromMap(Map<String, dynamic> map) {
    if (map == null) return null;
    return TenorResult(
      hasCaption: map['hascaption'] ?? false,
      hasaudio: map['hasaudio'] ?? false,
      shares: map['shares'] ?? 0,
      id: map['id'],
      title: map['title'],
      created: '${map['created']}',
      url: map['url'],
      itemurl: map['itemurl'],
      media: TenorGif.fromMap((map['media'] != null &&
              (map['media'] is List && map['media'].length != 0))
          ? map['media'][0]
          : <String, dynamic>{}),
    );
  }

  String toJson() => json.encode(toMap());

  static TenorResult fromJson(String source) =>
      TenorResult.fromMap(json.decode(source));

  @override
  String toString() {
    return 'TenorResult(hasCaption: $hasCaption, hasaudio: $hasaudio, shares: $shares, id: $id, title: $title, created: $created, url: $url, itemurl: $itemurl, media: $media)';
  }

  @override
  List<Object> get props =>
      [hasCaption, hasaudio, shares, id, title, created, url, itemurl, media];
}
